@@ -13,10 +13,8 @@ using namespace Qt::Literals::StringLiterals;
 #include "settings/kmailsettings.h"
 #include "undosend/undosendcombobox.h"
 #include <MailCommon/AccountConfigOrderDialog>
-#include <MessageComposer/MessageComposerSettings>
-#include <PimCommon/ConfigureImmutableWidgetUtils>
-using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <MailTransport/TransportManagementWidgetNg>
+#include <MessageComposer/MessageComposerSettings>
 using MailTransport::TransportManagementWidgetNg;
 #include <MailCommon/MailUtil>
 
@@ -83,7 +81,7 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
 {
     auto formLayout = new QFormLayout(this);
     // label: zero stretch ### FIXME more
-    formLayout->addRow(new QLabel(i18n("Outgoing accounts (add at least one):"), this));
+    formLayout->addRow(new QLabel(i18nc("@label:textbox", "Outgoing accounts (add at least one):"), this));
 
     auto tmw = new TransportManagementWidgetNg(this);
     tmw->layout()->setContentsMargins({});
@@ -91,20 +89,12 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
 
     // "confirm before send" check box:
     mConfirmSendCheck = new QCheckBox(i18n("&Confirm action"), this);
+    mConfirmSendCheck->setObjectName(u"kcfg_ConfirmBeforeSend"_s);
     formLayout->addRow(i18n("Before sending:"), mConfirmSendCheck);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mConfirmSendCheck, &QCheckBox::stateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
-#else
-    connect(mConfirmSendCheck, &QCheckBox::checkStateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
-#endif
 
     mCheckSpellingBeforeSending = new QCheckBox(i18n("Check spelling"), this);
+    mCheckSpellingBeforeSending->setObjectName(u"kcfg_CheckSpellingBeforeSend"_s);
     formLayout->addRow(QString(), mCheckSpellingBeforeSending);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mCheckSpellingBeforeSending, &QCheckBox::stateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
-#else
-    connect(mCheckSpellingBeforeSending, &QCheckBox::checkStateChanged, this, &AccountsPageSendingTab::slotEmitChanged);
-#endif
 
     // "send on check" combo:
     mSendOnCheckCombo = new QComboBox(this);
@@ -123,10 +113,10 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
 
     auto hLayout = new QHBoxLayout;
     mUndoSend = new QCheckBox(i18n("Enable Undo Send"), this);
+    mUndoSend->setObjectName(u"kcfg_EnabledUndoSend"_s);
     hLayout->addWidget(mUndoSend);
     connect(mUndoSend, &QCheckBox::toggled, this, [this](bool state) {
         mUndoSendComboBox->setEnabled(state);
-        slotEmitChanged();
     });
 
     mUndoSendComboBox = new UndoSendCombobox(this);
@@ -139,27 +129,18 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
 void AccountsPageSendingTab::doLoadFromGlobalSettings()
 {
     mSendOnCheckCombo->setCurrentIndex(KMailSettings::self()->sendOnCheck());
-    loadWidget(mConfirmSendCheck, KMailSettings::self()->confirmBeforeSendItem());
-    loadWidget(mCheckSpellingBeforeSending, KMailSettings::self()->checkSpellingBeforeSendItem());
-    loadWidget(mUndoSend, KMailSettings::self()->enabledUndoSendItem());
     mUndoSendComboBox->setDelay(KMailSettings::self()->undoSendDelay());
 }
 
 void AccountsPageSendingTab::doLoadOther()
 {
     mSendMethodCombo->setCurrentIndex(MessageComposer::MessageComposerSettings::self()->sendImmediate() ? 0 : 1);
-    loadWidget(mConfirmSendCheck, KMailSettings::self()->confirmBeforeSendItem());
-    loadWidget(mCheckSpellingBeforeSending, KMailSettings::self()->checkSpellingBeforeSendItem());
-    loadWidget(mUndoSend, KMailSettings::self()->enabledUndoSendItem());
     mUndoSendComboBox->setDelay(KMailSettings::self()->undoSendDelay());
 }
 
 void AccountsPageSendingTab::save()
 {
     KMailSettings::self()->setSendOnCheck(mSendOnCheckCombo->currentIndex());
-    saveCheckBox(mConfirmSendCheck, KMailSettings::self()->confirmBeforeSendItem());
-    saveCheckBox(mCheckSpellingBeforeSending, KMailSettings::self()->checkSpellingBeforeSendItem());
-    saveCheckBox(mUndoSend, KMailSettings::self()->enabledUndoSendItem());
     MessageComposer::MessageComposerSettings::self()->setSendImmediate(mSendMethodCombo->currentIndex() == 0);
     KMailSettings::self()->setUndoSendDelay(mUndoSendComboBox->delay());
 }
@@ -206,8 +187,8 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
     connect(mAccountsReceiving.customizeAccountOrder, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotCustomizeAccountOrder);
     mAccountsReceiving.mAccountsReceiving->disconnectAddAccountButton();
     auto accountMenu = new QMenu(this);
-    accountMenu->addAction(i18n("Add Mail Account..."), this, &AccountsPageReceivingTab::slotAddMailAccount);
-    accountMenu->addAction(i18n("Custom Account..."), this, &AccountsPageReceivingTab::slotAddCustomAccount);
+    accountMenu->addAction(i18n("Add Mail Account…"), this, &AccountsPageReceivingTab::slotAddMailAccount);
+    accountMenu->addAction(i18n("Custom Account…"), this, &AccountsPageReceivingTab::slotAddCustomAccount);
     mAccountsReceiving.mAccountsReceiving->addAccountButton()->setMenu(accountMenu);
 }
 
@@ -292,7 +273,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
     menu.addAction(switchOffline);
     connect(switchOffline, &QAction::toggled, this, &AccountsPageReceivingTab::slotOfflineOnShutdownChanged);
 
-    auto checkOnStartup = new QAction(i18n("Check mail on startup"), &menu);
+    auto checkOnStartup = new QAction(i18nc("@action", "Check mail on startup"), &menu);
     checkOnStartup->setCheckable(true);
     checkOnStartup->setChecked(CheckOnStartup);
     checkOnStartup->setData(ident);
