@@ -24,7 +24,7 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <templateparser/globalsettings_templateparser.h>
 #include <templateparser/templatesconfiguration_kfg.h>
 
-#include <KLDAPWidgets/LdapClientSearch>
+#include <KLDAPCore/LdapClientSearch>
 #include <PimCommonAkonadi/CompletionOrderEditor>
 #include <PimCommonAkonadi/RecentAddresses>
 using PimCommon::RecentAddresses;
@@ -116,6 +116,9 @@ QString ComposerPageGeneralTab::helpAnchor() const
 
 ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     : ConfigModuleTab(parent)
+    , mAutoAppSignFileCheck(new QCheckBox(MessageComposer::MessageComposerSettings::self()->autoTextSignatureItem()->label(), this))
+    , mTopQuoteCheck(new QCheckBox(MessageComposer::MessageComposerSettings::self()->prependSignatureItem()->label(), this))
+    , mDashDashCheck(new QCheckBox(MessageComposer::MessageComposerSettings::self()->dashDashSignatureItem()->label(), this))
 {
     // Main layout
     auto mainLayout = new QVBoxLayout(this);
@@ -128,7 +131,6 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     auto groupVBoxLayout = new QVBoxLayout();
 
     // "Automatically insert signature" checkbox
-    mAutoAppSignFileCheck = new QCheckBox(MessageComposer::MessageComposerSettings::self()->autoTextSignatureItem()->label(), this);
 
     QString helpText = i18n("Automatically insert the configured signature when starting to compose a message");
     mAutoAppSignFileCheck->setToolTip(helpText);
@@ -142,7 +144,6 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     groupVBoxLayout->addWidget(mAutoAppSignFileCheck);
 
     // "Insert signature above quoted text" checkbox
-    mTopQuoteCheck = new QCheckBox(MessageComposer::MessageComposerSettings::self()->prependSignatureItem()->label(), this);
     mTopQuoteCheck->setEnabled(false);
 
     helpText = i18n("Insert the signature above any quoted text");
@@ -158,7 +159,6 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     groupVBoxLayout->addWidget(mTopQuoteCheck);
 
     // "Prepend separator to signature" checkbox
-    mDashDashCheck = new QCheckBox(MessageComposer::MessageComposerSettings::self()->dashDashSignatureItem()->label(), this);
     mDashDashCheck->setEnabled(false);
 
     helpText = i18n("Insert the RFC-compliant signature separator (two dashes and a space on a line) before the signature");
@@ -297,7 +297,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mForwardTypeCombo->setToolTip(helpText);
     mForwardTypeCombo->setWhatsThis(helpText);
 
-    label = new QLabel(i18n("Default forwarding type:"), this);
+    label = new QLabel(i18nc("@label:textbox", "Default forwarding type:"), this);
     label->setBuddy(mForwardTypeCombo);
 
     connect(mForwardTypeCombo, &QComboBox::activated, this, &ComposerPageGeneralTab::slotEmitChanged);
@@ -326,18 +326,8 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
 
     // "Automatically request MDNs" checkbox
     mAutoRequestMDNCheck = new QCheckBox(KMailSettings::self()->requestMDNItem()->label(), this);
+    mAutoRequestMDNCheck->setObjectName(u"kcfg_RequestMDN"_s);
 
-    helpText = i18n(
-        "By default, request an MDN when starting to compose a message. You can select this on a per-message basis using \"Options - Request Disposition "
-        "Notification\"");
-    mAutoRequestMDNCheck->setToolTip(helpText);
-    mAutoRequestMDNCheck->setWhatsThis(helpText);
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mAutoRequestMDNCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-#else
-    connect(mAutoRequestMDNCheck, &QCheckBox::checkStateChanged, this, &ConfigModuleTab::slotEmitChanged);
-#endif
     groupGridLayout->addWidget(mAutoRequestMDNCheck, row, 0, 1, -1);
     ++row;
 
@@ -359,9 +349,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     // "Warn if too many recipients" checkbox/spinbox
     mRecipientCheck = new QCheckBox(KMailSettings::self()->tooManyRecipientsItem()->label(), this);
     mRecipientCheck->setObjectName("kcfg_TooManyRecipients"_L1);
-    helpText = i18n(KMailSettings::self()->tooManyRecipientsItem()->whatsThis().toUtf8().constData());
-    mRecipientCheck->setWhatsThis(helpText);
-    mRecipientCheck->setToolTip(i18n("Warn if too many recipients are specified"));
+    mRecipientCheck->setToolTip(i18nc("@info:tooltip", "Warn if too many recipients are specified"));
 
     mRecipientSpin = new QSpinBox(this);
     mRecipientSpin->setMaximum(100 /*max*/);
@@ -370,16 +358,8 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mRecipientSpin->setValue(5 /*init*/);
     mRecipientSpin->setObjectName("kcfg_RecipientThreshold"_L1);
     mRecipientSpin->setEnabled(false);
-    helpText = i18n(KMailSettings::self()->recipientThresholdItem()->whatsThis().toUtf8().constData());
-    mRecipientSpin->setWhatsThis(helpText);
-    mRecipientSpin->setToolTip(i18n("Set the maximum number of recipients for the warning"));
+    mRecipientSpin->setToolTip(i18nc("@info:tooltip", "Set the maximum number of recipients for the warning"));
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mRecipientCheck, &QCheckBox::stateChanged, this, &ComposerPageGeneralTab::slotEmitChanged);
-#else
-    connect(mRecipientCheck, &QCheckBox::checkStateChanged, this, &ComposerPageGeneralTab::slotEmitChanged);
-#endif
-    connect(mRecipientSpin, &QSpinBox::valueChanged, this, &ComposerPageGeneralTab::slotEmitChanged);
     // only enable the spinbox if the checkbox is checked
     connect(mRecipientCheck, &QCheckBox::toggled, mRecipientSpin, &QSpinBox::setEnabled);
 
@@ -397,7 +377,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
 
     helpText = i18n(
         "Only allow this many recipients to be specified for the message. This applies to doing a \"Reply to All\", entering recipients manually"
-        " or using the \"Select...\" picker.  Setting this limit helps you to avoid accidentally sending a message to too many people.  Note,"
+        " or using the \"Select…\" picker.  Setting this limit helps you to avoid accidentally sending a message to too many people.  Note,"
         " however, that it does not take account of distribution lists or mailing lists.");
     mMaximumRecipients->setToolTip(helpText);
     mMaximumRecipients->setWhatsThis(helpText);
@@ -436,7 +416,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mMaximumRecentAddress->setSpecialValueText(i18nc("No addresses are retained", "No save"));
     mMaximumRecentAddress->setEnabled(false);
 
-    label = new QLabel(i18n("Maximum recent addresses retained:"));
+    label = new QLabel(i18nc("@label:textbox", "Maximum recent addresses retained:"));
     label->setBuddy(mMaximumRecentAddress);
     label->setEnabled(false);
 
@@ -453,7 +433,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     ++row;
 
     // Configure All Address settings
-    auto configureCompletionButton = new QPushButton(i18n("Configure Completion..."), this);
+    auto configureCompletionButton = new QPushButton(i18nc("@action:button", "Configure Completion…"), this);
     connect(configureCompletionButton, &QAbstractButton::clicked, this, &ComposerPageGeneralTab::slotConfigureAddressCompletion);
     groupGridLayout->addWidget(configureCompletionButton, row, 1, 1, 2);
     groupGridLayout->setRowStretch(row, 1);
@@ -482,8 +462,6 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     label = new QLabel(KMailSettings::self()->autosaveIntervalItem()->label(), this);
     label->setBuddy(mAutoSave);
 
-    connect(mAutoSave, &QSpinBox::valueChanged, this, &ConfigModuleTab::slotEmitChanged);
-
     groupHBoxLayout->addWidget(label);
     groupHBoxLayout->addWidget(mAutoSave);
     groupHBoxLayout->addStretch();
@@ -539,7 +517,6 @@ void ComposerPageGeneralTab::doLoadFromGlobalSettings()
 
     loadWidget(mReplyUsingVisualFormat, TemplateParser::TemplateParserSettings::self()->replyUsingVisualFormatItem());
     loadWidget(mStripSignatureCheck, TemplateParser::TemplateParserSettings::self()->stripSignatureItem());
-    loadWidget(mAutoRequestMDNCheck, KMailSettings::self()->requestMDNItem());
     loadWidget(mWordWrapCheck, MessageComposer::MessageComposerSettings::self()->wordWrapItem());
 
     loadWidget(mWrapColumnSpin, MessageComposer::MessageComposerSettings::self()->lineWrapWidthItem());
@@ -571,7 +548,6 @@ void ComposerPageGeneralTab::save()
 
     saveCheckBox(mReplyUsingVisualFormat, TemplateParser::TemplateParserSettings::self()->replyUsingVisualFormatItem());
     saveCheckBox(mStripSignatureCheck, TemplateParser::TemplateParserSettings::self()->stripSignatureItem());
-    saveCheckBox(mAutoRequestMDNCheck, KMailSettings::self()->requestMDNItem());
     saveCheckBox(mWordWrapCheck, MessageComposer::MessageComposerSettings::self()->wordWrapItem());
 
     MessageComposer::MessageComposerSettings::self()->setAutoTextSignature(mAutoAppSignFileCheck->isChecked() ? QStringLiteral("auto")
@@ -595,7 +571,7 @@ void ComposerPageGeneralTab::save()
 
 void ComposerPageGeneralTab::slotConfigureAddressCompletion()
 {
-    KLDAPWidgets::LdapClientSearch search;
+    KLDAPCore::LdapClientSearch search;
     QPointer<PimCommon::CompletionConfigureDialog> dlg(new PimCommon::CompletionConfigureDialog(this));
     dlg->setRecentAddresses(PimCommon::RecentAddresses::self(MessageComposer::MessageComposerSettings::self()->config())->addresses());
     dlg->setLdapClientSearch(&search);
@@ -689,7 +665,8 @@ ComposerPageSubjectTab::ComposerPageSubjectTab(QWidget *parent)
     auto layout = new QVBoxLayout(group);
 
     // row 0: help text:
-    auto label = new QLabel(i18n("Recognize any sequence of the following prefixes (entries are case-insensitive regular expressions):"), group);
+    auto label =
+        new QLabel(i18nc("@label:textbox", "Recognize any sequence of the following prefixes (entries are case-insensitive regular expressions):"), group);
     label->setWordWrap(true);
     label->setAlignment(Qt::AlignLeft);
 
@@ -697,12 +674,12 @@ ComposerPageSubjectTab::ComposerPageSubjectTab(QWidget *parent)
     auto buttonCode = static_cast<PimCommon::SimpleStringListEditor::ButtonCode>(
         PimCommon::SimpleStringListEditor::Add | PimCommon::SimpleStringListEditor::Remove | PimCommon::SimpleStringListEditor::Modify);
     mReplyListEditor =
-        new PimCommon::SimpleStringListEditor(group, buttonCode, i18n("A&dd..."), i18n("Re&move"), i18n("Mod&ify..."), i18n("Enter new reply prefix:"));
+        new PimCommon::SimpleStringListEditor(group, buttonCode, i18n("A&dd…"), i18n("Re&move"), i18n("Mod&ify…"), i18n("Enter new reply prefix:"));
     mReplyListEditor->setRemoveDialogLabel(i18n("Do you want to remove reply prefix?"));
     connect(mReplyListEditor, &PimCommon::SimpleStringListEditor::changed, this, &ConfigModuleTab::slotEmitChanged);
     mReplyListEditor->setAddDialogLabel(i18n("Reply Prefix:"));
 
-    // row 2: "replace [...]" check box:
+    // row 2: "replace […]" check box:
     mReplaceReplyPrefixCheck = new QCheckBox(MessageCore::MessageCoreSettings::self()->replaceReplyPrefixItem()->label(), group);
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mReplaceReplyPrefixCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
@@ -719,18 +696,18 @@ ComposerPageSubjectTab::ComposerPageSubjectTab(QWidget *parent)
     layout = new QVBoxLayout(group);
 
     // row 0: help text:
-    label = new QLabel(i18n("Recognize any sequence of the following prefixes (entries are case-insensitive regular expressions):"), group);
+    label = new QLabel(i18nc("@label:textbox", "Recognize any sequence of the following prefixes (entries are case-insensitive regular expressions):"), group);
     label->setAlignment(Qt::AlignLeft);
     label->setWordWrap(true);
 
     // row 1: string list editor
     mForwardListEditor =
-        new PimCommon::SimpleStringListEditor(group, buttonCode, i18n("Add..."), i18n("Remo&ve"), i18n("Modify..."), i18n("Enter new forward prefix:"));
+        new PimCommon::SimpleStringListEditor(group, buttonCode, i18n("Add…"), i18n("Remo&ve"), i18n("Modify…"), i18n("Enter new forward prefix:"));
     mForwardListEditor->setRemoveDialogLabel(i18n("Do you want to remove forward prefix?"));
     mForwardListEditor->setAddDialogLabel(i18n("Forward Prefix:"));
     connect(mForwardListEditor, &PimCommon::SimpleStringListEditor::changed, this, &ConfigModuleTab::slotEmitChanged);
 
-    // row 3: "replace [...]" check box:
+    // row 3: "replace […]" check box:
     mReplaceForwardPrefixCheck = new QCheckBox(MessageCore::MessageCoreSettings::self()->replaceForwardPrefixItem()->label(), group);
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mReplaceForwardPrefixCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
@@ -745,6 +722,7 @@ ComposerPageSubjectTab::ComposerPageSubjectTab(QWidget *parent)
 
 void ComposerPageSubjectTab::doLoadFromGlobalSettings()
 {
+    qDebug() << " void ComposerPageSubjectTab::doLoadFromGlobalSettings()";
     loadWidget(mReplyListEditor, MessageCore::MessageCoreSettings::self()->replyPrefixesItem());
     loadWidget(mForwardListEditor, MessageCore::MessageCoreSettings::self()->forwardPrefixesItem());
     loadWidget(mReplaceForwardPrefixCheck, MessageCore::MessageCoreSettings::self()->replaceForwardPrefixItem());
@@ -761,11 +739,9 @@ void ComposerPageSubjectTab::save()
 
 void ComposerPageSubjectTab::doResetToDefaultsOther()
 {
+    qDebug() << " void ComposerPageSubjectTab::doResetToDefaultsOther()";
     const bool bUseDefaults = MessageComposer::MessageComposerSettings::self()->useDefaults(true);
-    loadWidget(mReplyListEditor, MessageCore::MessageCoreSettings::self()->replyPrefixesItem());
-    loadWidget(mForwardListEditor, MessageCore::MessageCoreSettings::self()->forwardPrefixesItem());
-    loadWidget(mReplaceForwardPrefixCheck, MessageCore::MessageCoreSettings::self()->replaceForwardPrefixItem());
-    loadWidget(mReplaceReplyPrefixCheck, MessageCore::MessageCoreSettings::self()->replaceReplyPrefixItem());
+    doLoadFromGlobalSettings();
     MessageComposer::MessageComposerSettings::self()->useDefaults(bUseDefaults);
 }
 
@@ -776,11 +752,12 @@ QString ComposerPageHeadersTab::helpAnchor() const
 
 ComposerPageHeadersTab::ComposerPageHeadersTab(QWidget *parent)
     : ConfigModuleTab(parent)
+    , mCreateOwnMessageIdCheck(new QCheckBox(i18n("&Use custom message-id suffix"), this))
+    , mMessageIdSuffixEdit(new QLineEdit(this))
 {
     auto vlay = new QVBoxLayout(this);
 
     // "Use custom Message-Id suffix" checkbox:
-    mCreateOwnMessageIdCheck = new QCheckBox(i18n("&Use custom message-id suffix"), this);
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     connect(mCreateOwnMessageIdCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
 #else
@@ -791,12 +768,11 @@ ComposerPageHeadersTab::ComposerPageHeadersTab(QWidget *parent)
     // "Message-Id suffix" line edit and label:
     auto hlay = new QHBoxLayout(); // inherits spacing
     vlay->addLayout(hlay);
-    mMessageIdSuffixEdit = new QLineEdit(this);
     mMessageIdSuffixEdit->setClearButtonEnabled(true);
     // only ASCII letters, digits, plus, minus and dots are allowed
     auto messageIdSuffixValidator = new QRegularExpressionValidator(QRegularExpression(QStringLiteral("[a-zA-Z0-9+-]+(?:\\.[a-zA-Z0-9+-]+)*")), this);
     mMessageIdSuffixEdit->setValidator(messageIdSuffixValidator);
-    auto label = new QLabel(i18n("Custom message-&id suffix:"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Custom message-&id suffix:"), this);
     label->setBuddy(mMessageIdSuffixEdit);
     label->setEnabled(false); // since !mCreateOwnMessageIdCheck->isChecked()
     mMessageIdSuffixEdit->setEnabled(false);
@@ -808,7 +784,7 @@ ComposerPageHeadersTab::ComposerPageHeadersTab(QWidget *parent)
 
     // horizontal rule and "custom header fields" label:
     vlay->addWidget(new KSeparator(Qt::Horizontal, this));
-    vlay->addWidget(new QLabel(i18n("Define custom mime header fields:"), this));
+    vlay->addWidget(new QLabel(i18nc("@label:textbox", "Define custom mime header fields:"), this));
 
     // "custom header fields" listbox:
     auto glay = new QGridLayout(); // inherits spacing
@@ -829,7 +805,7 @@ ComposerPageHeadersTab::ComposerPageHeadersTab(QWidget *parent)
     connect(button, &QAbstractButton::clicked, this, &ComposerPageHeadersTab::slotNewMimeHeader);
     button->setAutoDefault(false);
     glay->addWidget(button, 0, 2);
-    mRemoveHeaderButton = new QPushButton(i18n("Re&move"), this);
+    mRemoveHeaderButton = new QPushButton(i18nc("@action:button", "Re&move"), this);
     connect(mRemoveHeaderButton, &QAbstractButton::clicked, this, &ComposerPageHeadersTab::slotRemoveMimeHeader);
     button->setAutoDefault(false);
     glay->addWidget(mRemoveHeaderButton, 1, 2);
@@ -848,7 +824,7 @@ ComposerPageHeadersTab::ComposerPageHeadersTab(QWidget *parent)
     mTagValueEdit = new QLineEdit(this);
     mTagValueEdit->setClearButtonEnabled(true);
     mTagValueEdit->setEnabled(false);
-    mTagValueLabel = new QLabel(i18n("&Value:"), this);
+    mTagValueLabel = new QLabel(i18nc("@label:textbox", "&Value:"), this);
     mTagValueLabel->setBuddy(mTagValueEdit);
     mTagValueLabel->setEnabled(false);
     glay->addWidget(mTagValueLabel, 4, 0);
@@ -1029,17 +1005,13 @@ ComposerPageAttachmentsTab::ComposerPageAttachmentsTab(QWidget *parent)
 
     // "Enable detection of missing attachments" check box
     mMissingAttachmentDetectionCheck = new QCheckBox(i18n("E&nable detection of missing attachments"), this);
-    mMissingAttachmentDetectionCheck->setChecked(true);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mMissingAttachmentDetectionCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-#else
-    connect(mMissingAttachmentDetectionCheck, &QCheckBox::checkStateChanged, this, &ConfigModuleTab::slotEmitChanged);
-#endif
+    mMissingAttachmentDetectionCheck->setObjectName(u"kcfg_ShowForgottenAttachmentWarning"_s);
     vlay->addWidget(mMissingAttachmentDetectionCheck);
 
     // "Attachment key words" label and string list editor
-    auto label = new QLabel(i18n("Recognize any of the following key words as "
-                                 "intention to attach a file:"),
+    auto label = new QLabel(i18nc("@label:textbox",
+                                  "Recognize any of the following key words as "
+                                  "intention to attach a file:"),
                             this);
     label->setAlignment(Qt::AlignLeft);
     label->setWordWrap(true);
@@ -1049,17 +1021,17 @@ ComposerPageAttachmentsTab::ComposerPageAttachmentsTab(QWidget *parent)
     auto buttonCode = static_cast<PimCommon::SimpleStringListEditor::ButtonCode>(
         PimCommon::SimpleStringListEditor::Add | PimCommon::SimpleStringListEditor::Remove | PimCommon::SimpleStringListEditor::Modify);
     mAttachWordsListEditor =
-        new PimCommon::SimpleStringListEditor(this, buttonCode, i18n("A&dd..."), i18n("Re&move"), i18n("Mod&ify..."), i18n("Enter new key word:"));
+        new PimCommon::SimpleStringListEditor(this, buttonCode, i18n("A&dd…"), i18n("Re&move"), i18n("Mod&ify…"), i18n("Enter new key word:"));
+    mAttachWordsListEditor->setObjectName(u"kcfg_AttachmentKeywords"_s);
     mAttachWordsListEditor->setRemoveDialogLabel(i18n("Do you want to remove this attachment word?"));
     mAttachWordsListEditor->setAddDialogLabel(i18n("Attachment Word:"));
-    connect(mAttachWordsListEditor, &PimCommon::SimpleStringListEditor::changed, this, &ConfigModuleTab::slotEmitChanged);
     vlay->addWidget(mAttachWordsListEditor);
 
     connect(mMissingAttachmentDetectionCheck, &QAbstractButton::toggled, label, &QWidget::setEnabled);
     connect(mMissingAttachmentDetectionCheck, &QAbstractButton::toggled, mAttachWordsListEditor, &QWidget::setEnabled);
 
     auto layAttachment = new QHBoxLayout;
-    label = new QLabel(i18n("Maximum Attachment Size:"), this);
+    label = new QLabel(i18nc("@label:textbox", "Maximum Attachment Size:"), this);
     label->setAlignment(Qt::AlignLeft);
     layAttachment->addWidget(label);
 
@@ -1075,17 +1047,12 @@ ComposerPageAttachmentsTab::ComposerPageAttachmentsTab(QWidget *parent)
 
 void ComposerPageAttachmentsTab::doLoadFromGlobalSettings()
 {
-    loadWidget(mMissingAttachmentDetectionCheck, KMailSettings::self()->showForgottenAttachmentWarningItem());
-    loadWidget(mAttachWordsListEditor, KMailSettings::self()->attachmentKeywordsItem());
     const int maximumAttachmentSize(MessageCore::MessageCoreSettings::self()->maximumAttachmentSize());
     mMaximumAttachmentSize->setValue(maximumAttachmentSize == -1 ? -1 : MessageCore::MessageCoreSettings::self()->maximumAttachmentSize() / 1024);
 }
 
 void ComposerPageAttachmentsTab::save()
 {
-    saveCheckBox(mMissingAttachmentDetectionCheck, KMailSettings::self()->showForgottenAttachmentWarningItem());
-    saveSimpleStringListEditor(mAttachWordsListEditor, KMailSettings::self()->attachmentKeywordsItem());
-
     const int maximumAttachmentSize(mMaximumAttachmentSize->value());
     MessageCore::MessageCoreSettings::self()->setMaximumAttachmentSize(maximumAttachmentSize == -1 ? -1 : maximumAttachmentSize * 1024);
 }
@@ -1126,13 +1093,13 @@ void ComposerPageAutoCorrectionTab::doResetToDefaultsOther()
 
 ComposerPageAutoImageResizeTab::ComposerPageAutoImageResizeTab(QWidget *parent)
     : ConfigModuleTab(parent)
+    , mAutoResizeWidget(new MessageComposer::ImageScalingWidget(this))
 {
     auto vlay = new QVBoxLayout(this);
     vlay->setSpacing(0);
     vlay->setContentsMargins({});
-    autoResizeWidget = new MessageComposer::ImageScalingWidget(this);
-    vlay->addWidget(autoResizeWidget);
-    connect(autoResizeWidget, &MessageComposer::ImageScalingWidget::changed, this, &ConfigModuleTab::slotEmitChanged);
+    vlay->addWidget(mAutoResizeWidget);
+    connect(mAutoResizeWidget, &MessageComposer::ImageScalingWidget::changed, this, &ConfigModuleTab::slotEmitChanged);
 }
 
 QString ComposerPageAutoImageResizeTab::helpAnchor() const
@@ -1142,17 +1109,17 @@ QString ComposerPageAutoImageResizeTab::helpAnchor() const
 
 void ComposerPageAutoImageResizeTab::save()
 {
-    autoResizeWidget->writeConfig();
+    mAutoResizeWidget->writeConfig();
 }
 
 void ComposerPageAutoImageResizeTab::doLoadFromGlobalSettings()
 {
-    autoResizeWidget->loadConfig();
+    mAutoResizeWidget->loadConfig();
 }
 
 void ComposerPageAutoImageResizeTab::doResetToDefaultsOther()
 {
-    autoResizeWidget->resetToDefault();
+    mAutoResizeWidget->resetToDefault();
 }
 
 #include "moc_configurecomposerpage.cpp"
